aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2019-09-07 02:24:44 +0200
committerSven Gothel <[email protected]>2019-09-07 02:24:44 +0200
commit7f6d030ba91060aa4dedbf4311290c5cf5f61c4a (patch)
tree6cc8369f45e5afbb0e704effa3e32ca75c225365
parent56a9f30fde429663514c6d5c810af2c43cb7ebf3 (diff)
Bug 1392: X11PixmapGLXDrawable::createPixmap() requires X11GLXGraphicsConfiguration having a valid XVisualInfo
Therefor X11GLXGraphicsConfiguration::GLXFBConfig2GLCapabilities(..) also needs to clean the GLGraphicsConfigurationUtil.BITMAP_BIT from drawableTypeBits and if all removed, drop the FBConfig.
-rw-r--r--src/jogl/classes/jogamp/opengl/x11/glx/X11GLXGraphicsConfiguration.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/jogl/classes/jogamp/opengl/x11/glx/X11GLXGraphicsConfiguration.java b/src/jogl/classes/jogamp/opengl/x11/glx/X11GLXGraphicsConfiguration.java
index caff16812..b5ad67dc7 100644
--- a/src/jogl/classes/jogamp/opengl/x11/glx/X11GLXGraphicsConfiguration.java
+++ b/src/jogl/classes/jogamp/opengl/x11/glx/X11GLXGraphicsConfiguration.java
@@ -323,8 +323,8 @@ public class X11GLXGraphicsConfiguration extends X11GraphicsConfiguration implem
if(DEBUG) {
System.err.println("X11GLXGraphicsConfiguration.GLXFBConfig2GLCapabilities: Null XVisualInfo for FBConfigID 0x" + Integer.toHexString(fbcfgid));
}
- // onscreen must have an XVisualInfo
- drawableTypeBits &= ~(GLGraphicsConfigurationUtil.WINDOW_BIT | GLGraphicsConfigurationUtil.FBO_BIT);
+ // onscreen, FBO and bitmap must have an XVisualInfo
+ drawableTypeBits &= ~(GLGraphicsConfigurationUtil.WINDOW_BIT | GLGraphicsConfigurationUtil.FBO_BIT | GLGraphicsConfigurationUtil.BITMAP_BIT);
}
if( 0 == drawableTypeBits ) {
if(DEBUG) {